<!--
 * @Author: Wenyu Ouyang
 * @Date: 2021-12-05 22:13:21
 * @LastEditTime: 2022-09-08 14:36:46
 * @LastEditors: Wenyu Ouyang
 * @Description: README for hydrodataset
 * @FilePath: \hydrodataset\README.md
 * Copyright (c) 2021-2022 Wenyu Ouyang. All rights reserved.
-->
# hydrodataset


[![image](https://img.shields.io/pypi/v/hydrodataset.svg)](https://pypi.python.org/pypi/hydrodataset)
[![image](https://img.shields.io/conda/vn/conda-forge/hydrodataset.svg)](https://anaconda.org/conda-forge/hydrodataset)


**A Python package for downloading and reading hydrological datasets**

-   Free software: MIT license
-   Documentation: https://OuyangWenyu.github.io/hydrodataset

## Features

HydroDataset is designed to help (1) download, (2) read, (3)format and (4) visualize some datasets through a
core language (Python) for watershed hydrological modeling.

**Note**: But now this repository is still developing and only supports quite simple functions such as downloading and reading data for watersheds.

Now the dataset zoo list includes:

| **Number** | **Dataset** | **Description**                                         | **Format**        |
| ---------- | ----------- | ------------------------------------------------------- | ----------------- |
| 1          | **CAMELS**  | CAMELS series datasets including CAMELS-AUS/BR/CL/GB/US | Dataset Directory |

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.

It was inspired by [HydroData](https://github.com/mikejohnson51/HydroData) and used some tools made by [cheginit](https://github.com/cheginit).
